import {
    AxisStyle,
    CentileStyle,
    ChartStyle,
    GridlineStyle,
    MeasurementStyle,
    SDSStyle,
} from '../../interfaces/StyleObjects';

/*
The following styles are provided to the RCPCHChart component, and define the styles in the Traditional (Boys) theme
*/

export const traditionalBoyAxisStyles: AxisStyle = {
    axisStroke: '#000000',
    axisLabelTextStyle: {
        name: 'Arial',
        colour: '#000000',
        size: 10,
        style: 'normal',
    },
    tickLabelTextStyle: {
        name: 'Arial',
        colour: '#000000',
        size: 8,
        style: 'normal',
    },
};

export const traditionalBoyChartStyles: ChartStyle = {
    backgroundColour: '#FFFFFF',
    titleStyle: {
        name: 'Arial',
        colour: '#000000',
        size: 14,
        weight: '700',
    },
    subTitleStyle: {
        name: 'Arial',
        colour: '#000000',
        size: 12,
        style: 'italic',
    },
    tooltipBackgroundColour: '#66c8eb',
    tooltipStroke: '#66c8eb',
    tooltipTextStyle: {
        name: 'Montserrat',
        colour: '#FFFFFF',
        size: 14,
        style: 'normal',
    },
    termFill: '#CDCDCD',
    termStroke: '#CDCDCD',
    toggleButtonInactiveColour: '#66c8eb',
    toggleButtonActiveColour: '#00a3de',
    toggleButtonTextStyle: {
        name: 'Arial',
        colour: '#FFFFFF',
        size: 14,
        style: 'normal',
    },
};

export const traditionalBoyGridlineStyles: GridlineStyle = {
    gridlines: true,
    stroke: '#d9d9d9',
    strokeWidth: 0.25,
    dashed: false,
};

export const traditionalBoyCentileStyles: CentileStyle = {
    sdsStroke: '#A9A9A9',
    centileStroke: '#00a3de',
    delayedPubertyAreaFill: '#66c8eb',
    midParentalCentileStroke: '#00a3de',
    midParentalAreaFill: '#00a3de',
};

export const traditionalBoyMeasurementStyles: MeasurementStyle = {
    measurementFill: '#000000',
    highlightedMeasurementFill: '#00a3de',
    eventTextStyle: {
        name: 'Montserrat',
        colour: '#000000',
        size: 12,
        style: 'normal',
    },
};
export const traditionalBoySDSStyles: SDSStyle = {
    heightStroke: '#a3deff',
    weightStroke: '#a3de7f',
    ofcStroke: '#a3de3f',
    bmiStroke: '#a3de1f',
};

/*
The following styles are provided to the CentileChart component, and are a step downstream from the user. 
The user style props, passed into the RCPCHChart component, have been processed by the makeAllStyles function and returned in this format
*/

export const traditionalBoysStyles = {
    chartMisc: {
        background: {
            fill: '#FFFFFF',
        },
    },
    toolTipFlyout: {
        stroke: '#66c8eb',
        fill: '#66c8eb',
    },
    toolTipMain: {
        textAnchor: 'start',
        strokeWidth: 0.25,
        fill: '#FFFFFF',
        fontFamily: 'Montserrat',
        fontWeight: 'normal',
    },
    chartTitle: {
        fontFamily: 'Arial',
        color: '#000000',
        fontSize: 14,
        fontWeight: 'bold',
        fontStyle: 'normal',
    },
    chartSubTitle: {
        fontFamily: 'Arial',
        color: '#000000',
        fontSize: 14,
        fontWeight: 'normal',
        fontStyle: 'normal',
    },
    termArea: {
        data: {
            fill: '#CDCDCD',
            stroke: '#CDCDCD',
        },
    },
    xAxis: {
        axis: {
            stroke: '#000000',
            strokeWidth: 1,
        },
        axisLabel: {
            fontSize: 10,
            padding: 20,
            fill: '000000',
            fontFamily: 'Arial',
        },
        ticks: {
            stroke: '000000',
        },
        tickLabels: {
            fontSize: 8,
            padding: 5,
            fill: '000000',
            color: '000000',
            fontFamily: 'Arial',
        },
        grid: {
            stroke: '#d9d9d9',
            strokeWidth: 0.25,
            strokeDasharray: '',
        },
    },
    xTicklabel: {
        fill: '000000',
        fontSize: 8,
        fontFamily: 'Arial',
    },
    yAxis: {
        axis: {
            stroke: '#000000',
            strokeWidth: 1,
        },
        axisLabel: {
            fontSize: 10,
            padding: 25,
            fill: '000000',
            fontFamily: 'Arial',
        },
        ticks: {
            stroke: '000000',
        },
        tickLabels: {
            fontSize: 8,
            padding: 5,
            fill: '000000',
            fontFamily: 'Arial',
        },
        grid: {
            stroke: '#d9d9d9',
            strokeWidth: 0.25,
            strokeDasharray: '',
        },
    },
    delayedPubertyArea: {
        data: {
            stroke: '#66c8eb',
            fill: '#66c8eb',
            strokeWidth: 1.5,
        },
    },
    delayedPubertyThresholdLine: {
        data: {
            stroke: '#000000',
            strokeWidth: 1,
        },
    },
    delayedPubertyThresholdLabel: {
        fontSize: 9,
        fill: '000000',
        fontFamily: 'Arial',
        textAlign: 'start',
    },
    sdsLine: {
        data: {
            stroke: '#A9A9A9',
            strokeWidth: 1,
            strokeLinecap: 'round',
            strokeDasharray: '5 5',
        },
    },
    dashedCentile: {
        data: {
            stroke: '#00a3de',
            strokeWidth: 1.5,
            strokeLinecap: 'round',
            strokeDasharray: '5 5',
        },
    },
    continuousCentile: {
        data: {
            stroke: '#00a3de',
            strokeWidth: 1.5,
            strokeLinecap: 'round',
        },
    },
    centileLabel: {
        fill: '#00a3de',
        fontSize: 6,
    },
    heightSDS: {
        data: {
            stroke: '#00a3deff',
            strokeWidth: 1.5,
            strokeLinecap: 'round',
        },
    },
    weightSDS: {
        data: {
            stroke: '#00a3de7f',
            strokeWidth: 1.5,
            strokeLinecap: 'round',
        },
    },
    ofcSDS: {
        data: {
            stroke: '#00a3de3f',
            strokeWidth: 1.5,
            strokeLinecap: 'round',
        },
    },
    bmiSDS: {
        data: {
            stroke: '#00a3de1f',
            strokeWidth: 1.5,
            strokeLinecap: 'round',
        },
    },
    midParentalCentile: {
        data: {
            stroke: '#00a3de',
            strokeWidth: 1.5,
            strokeLinecap: 'round',
            strokeOpacity: 1,
        },
    },
    midParentalSDS: {
        data: {
            stroke: '#00a3de',
            strokeWidth: 1.5,
            strokeLinecap: 'round',
            strokeOpacity: 1,
            strokeDasharray: '2 5',
        },
    },
    midParentalArea: {
        data: {
            fill: '#66c8eb',
            opacity: 0.5,
        },
    },
    measurementPoint: {
        data: {
            fill: '#000000',
        },
    },
    measurementLinkLine: {
        data: {
            stroke: '#000000',
            strokeWidth: 1.25,
        },
    },
    highlightedMeasurementFill: {
        data: {
            fill: '#00a3de',
        },
    },
    toggleStyle: {
        activeColour: '#00a3de',
        inactiveColour: '#66c8eb',
        fontFamily: 'Arial',
        color: '#FFFFFF',
        fontSize: 14,
        fontWeight: 'normal',
        fontStyle: 'normal',
    },
    eventTextStyle: {
        name: 'Montserrat',
        colour: '#000000',
        size: 14,
        style: 'normal',
    },
    toggleTooltipStyle: {
        backgroundColor: '#333',
        color: '#fff',
        fontSize: 14,
        fontFamily: 'Montserrat',
        fontWeight: 400,
        fontStyle: 'regular',
        borderRadius: 4
    },
    referenceTextStyle: {
        fontSize: 8,
        fontFamily: 'Arial',
        color: '#000000',
        fontWeight: 200,
        fontStyle: 'normal',
    }
};
